@@ -1,40 +1,16 @@
 """\
-Allows nested imports, a la Java. It installs a harmless meta import-hook that 
+Allows nested imports, a la Java. Nimp installs a harmless meta import-hook that 
 adds support for *nested packages*, i.e., multiple packages that "live" under a 
 common namespace. This is the idiom in Java, where you have packages like 
-``com.foo.bar.spam`` and ``com.foo.bar.eggs``, as well as in Haskell. 
-Nimp basically allows packages to "inject" themselves into shared namespaces.
-
-Compatible with Python 2.3 and up and 3.0 and up
-
-Usage::
+``com.foo.bar.spam`` and ``com.foo.bar.eggs``, as well as in Haskell and several 
+other languages. Nimp basically allows packages to "inject" themselves into 
+shared namespaces.
 
+Usage:
   import nimp
   nimp.install()
 
-Example Layout
---------------
-Assume the following directory structure, say, in your ``site-packages``::
-
-  com.ibm.storage/
-    files...
-  com.ibm.storage.plugins/
-    files...
-  com.ibm.pythontools/
-    files...
-
-Using Nimp, the following imports will work as expected::
-  
-  import com                              # a namespace package (empty)
-  import com.ibm                          # a namespace package (empty)
-  import com.ibm.pythontools              # a real package
-  com.ibm.pythontools.myfunc(1,2,3)
-  
-  # and of course using `from` works too
-  from com.ibm.storage import ScsiDisk    
-  
-  # note how the `plugins` package was "injected" into `storage`
-  from com.ibm.storage.plugins import MySQLPlugin
+See http://pypi.python.org/pypi/nimp for more info.
 """
 import os
 import sys
@@ -45,14 +21,18 @@ class _Nimp(object):
     def __init__(self):
         self.cache = {}
     
-    @staticmethod
-    def _get_name_prefixes(dotted_name):
+    def _get_name_prefixes(self, name):
+        if "-" in name:
+            sep = "-"
+        else:
+            sep = "."
         i = -1
-        while i is not None:
-            i = dotted_name.find(".", i+1)
+        while True:
+            i = name.find(sep, i+len(sep))
             if i < 0:
-                i = None
-            yield dotted_name[0:i]
+                yield name
+                break
+            yield name[:i]
     
     def _find_all(self, fullname):
         assert fullname not in self.cache
@@ -61,18 +41,19 @@ class _Nimp(object):
                 continue
             for fn in os.listdir(path):
                 fullpath = os.path.join(path, fn)
-                if not os.path.isdir(fullpath) or "." not in fn or not fn.startswith(fullname):
+                if not fn.startswith(fullname) or ("-" not in fn and "." not in fn):
                     continue
-                for pref in self._get_name_prefixes(fn):
-                    fullpath = os.path.join(path, pref)
+                if not os.path.isdir(fullpath):
+                    continue
+                for prefix in self._get_name_prefixes(fn):
+                    fullpath = os.path.join(path, prefix)
+                    modname = prefix.replace("-", ".")
                     if os.path.exists(fullpath):
-                        if pref in self.cache and self.cache[pref] != fullpath:
-                            raise ImportError("%r duplicated: %s and %s" % (pref, fullpath, self.cache[pref]))
-                        self.cache[pref] = fullpath # real
-                    else:
-                        if pref in self.cache and self.cache[pref] is not None:
-                            continue # do not override real
-                        self.cache[pref] = None # namespace only
+                        if modname in self.cache and self.cache[modname] != fullpath:
+                            raise ImportError("%r duplicated: %s and %s" % (modname, fullpath, self.cache[modname]))
+                        self.cache[modname] = fullpath # real
+                    elif modname not in self.cache:
+                        self.cache[modname] = None # namespace only
     
     def clear_cache(self):
         self.cache.clear()
@@ -100,7 +81,7 @@ class _Nimp(object):
                     mod.__file__ = "<namespace module>"
                     mod.__path__ = []
                 else:
-                    info = imp.find_module(fullname, [os.path.dirname(path)])
+                    info = imp.find_module(os.path.basename(path), [os.path.dirname(path)])
                     mod = imp.load_module(fullname, *info)
                     # replace the stub in sys.modules
                     sys.modules[fullname] = mod
@@ -133,3 +114,5 @@ def uninstall():
     _installed = False
 
 
+
+
